==> Release_C2.0.3.zip: Release C2.0.3/software/storetw/application/DW_GRANTS.sql <==
/*******************************************************
Filename		:  DW_GRANTS.sql
Release 		:  C2.0.2
SIR			:  1559, 1557
Description		:  Grants execute privileges to STORETWEB on STORETW web procedures.
Author			:  Joseph Wilson
Date			:  11/04/2002
			   06/17/2003 -- added result application pages
			   08/05/2003 -- added new procs since last 1.1 beta
			   08/11/2003 -- added act medium and community sampled-act intent -JW
			   11/10/2003 -- added blob and zip download pages; added JAVA permissions -JW
			   11/14/2003 -- added new JAVA permissions -JW
			   11/17/2003 -- added DW_result_download_zip and DW_station_download_zip -JW
			   01/22/2004 -- SIR 1586 - seperated grants, synonmys, and permissions into 3 scripts -JW
			   07/28/2004 -- added DW_STATIONCRITERIA_STN -JW
Comments		:  
**********************************************************/
SPOOL DW_GRANTS.LOG
--CONNECT STORETW/STORETW@STORET.SDC
GRANT EXECUTE ON DW_BIO_RESULTCRITERIA_GEO TO STORETWEB;
GRANT EXECUTE ON DW_BIO_RESULTCRITERIA_PROJECT TO STORETWEB;
GRANT EXECUTE ON DW_BIO_RESULTCRITERIA_STATION TO STORETWEB;
GRANT EXECUTE ON DW_BOTTOM_OF_PAGE TO STORETWEB;
GRANT EXECUTE ON DW_CHAR_ALIAS_POPUP TO STORETWEB;
GRANT EXECUTE ON DW_COUNTY_POPUP TO STORETWEB;
GRANT EXECUTE ON DW_DATE_SELECT TO STORETWEB;
GRANT EXECUTE ON DW_DISPLAY_CALENDAR TO STORETWEB;
GRANT EXECUTE ON DW_EXTREF_POPUP TO STORETWEB;
GRANT EXECUTE ON DW_GEO_SELECT TO STORETWEB;
GRANT EXECUTE ON DW_HAB_RESULTCRITERIA_GEO TO STORETWEB;
GRANT EXECUTE ON DW_HAB_RESULTCRITERIA_PROJECT TO STORETWEB;
GRANT EXECUTE ON DW_HAB_RESULTCRITERIA_STATION TO STORETWEB;
GRANT EXECUTE ON DW_HOME TO STORETWEB;
GRANT EXECUTE ON DW_HUC_POPUP TO STORETWEB;
GRANT EXECUTE ON DW_PROJECT_SELECT TO STORETWEB;
GRANT EXECUTE ON DW_PROJ_POPUP TO STORETWEB;
GRANT EXECUTE ON DW_RESULTCRITERIA_GEO TO STORETWEB;
GRANT EXECUTE ON DW_RESULTCRITERIA_PROJECT TO STORETWEB;
GRANT EXECUTE ON DW_RESULTCRITERIA_STATION TO STORETWEB;
GRANT EXECUTE ON DW_RESULT_COUNT TO STORETWEB;
GRANT EXECUTE ON DW_RESULT_DOWNLOAD_CUSTOM TO STORETWEB;
GRANT EXECUTE ON DW_RESULT_HUB_CUSTOM TO STORETWEB;
GRANT EXECUTE ON DW_STATIONCRITERIA TO STORETWEB;
GRANT EXECUTE ON DW_STATION_COUNT TO STORETWEB;
GRANT EXECUTE ON DW_STATION_DOWNLOAD_CUSTOM TO STORETWEB;
GRANT EXECUTE ON DW_STATION_HUB_CUSTOM TO STORETWEB;
GRANT EXECUTE ON DW_STATION_POPUP TO STORETWEB;
GRANT EXECUTE ON DW_STATION_SELECT TO STORETWEB;
GRANT EXECUTE ON DW_TOP_OF_PAGE TO STORETWEB;
GRANT EXECUTE ON DW_medium_select TO STORETWEB;
GRANT EXECUTE ON DW_intent_community_select TO STORETWEB;
GRANT EXECUTE ON DW_BLOB_DOWNLOAD TO STORETWEB;
GRANT EXECUTE ON DW_RESULT_DOWNLOAD_ZIP TO STORETWEB;
GRANT EXECUTE ON DW_STATION_DOWNLOAD_ZIP TO STORETWEB;
GRANT EXECUTE ON DW_STATIONCRITERIA_STN TO STORETWEB;

SPOOL OFF

==> Release_C2_0_5.zip: Release C2.0.5/software/storetw/application/DW_GRANTS.sql <==
/*******************************************************
Filename		:  DW_GRANTS.sql
Release 		:  C2.0.2, C2.0.5
SIR			:  1559, 1557, 1633
Description		:  Grants execute privileges to STORETWEB on STORETW web procedures.
Author			:  Joseph Wilson
Date			:  11/04/2002
			   06/17/2003 -- added result application pages
			   08/05/2003 -- added new procs since last 1.1 beta
			   08/11/2003 -- added act medium and community sampled-act intent -JW
			   11/10/2003 -- added blob and zip download pages; added JAVA permissions -JW
			   11/14/2003 -- added new JAVA permissions -JW
			   11/17/2003 -- added DW_result_download_zip and DW_station_download_zip -JW
			   01/22/2004 -- SIR 1586 - seperated grants, synonmys, and permissions into 3 scripts -JW
			   07/28/2004 -- added DW_STATIONCRITERIA_STN -JW
			   08/17/2005 -- added DW_batch_download_pickup -GT
Comments		:  
**********************************************************/
SPOOL DW_GRANTS.LOG
--CONNECT STORETW/STORETW@STORET.SDC
GRANT EXECUTE ON DW_BIO_RESULTCRITERIA_GEO TO STORETWEB;
GRANT EXECUTE ON DW_BIO_RESULTCRITERIA_PROJECT TO STORETWEB;
GRANT EXECUTE ON DW_BIO_RESULTCRITERIA_STATION TO STORETWEB;
GRANT EXECUTE ON DW_BOTTOM_OF_PAGE TO STORETWEB;
GRANT EXECUTE ON DW_CHAR_ALIAS_POPUP TO STORETWEB;
GRANT EXECUTE ON DW_COUNTY_POPUP TO STORETWEB;
GRANT EXECUTE ON DW_DATE_SELECT TO STORETWEB;
GRANT EXECUTE ON DW_DISPLAY_CALENDAR TO STORETWEB;
GRANT EXECUTE ON DW_EXTREF_POPUP TO STORETWEB;
GRANT EXECUTE ON DW_GEO_SELECT TO STORETWEB;
GRANT EXECUTE ON DW_HAB_RESULTCRITERIA_GEO TO STORETWEB;
GRANT EXECUTE ON DW_HAB_RESULTCRITERIA_PROJECT TO STORETWEB;
GRANT EXECUTE ON DW_HAB_RESULTCRITERIA_STATION TO STORETWEB;
GRANT EXECUTE ON DW_HOME TO STORETWEB;
GRANT EXECUTE ON DW_HUC_POPUP TO STORETWEB;
GRANT EXECUTE ON DW_PROJECT_SELECT TO STORETWEB;
GRANT EXECUTE ON DW_PROJ_POPUP TO STORETWEB;
GRANT EXECUTE ON DW_RESULTCRITERIA_GEO TO STORETWEB;
GRANT EXECUTE ON DW_RESULTCRITERIA_PROJECT TO STORETWEB;
GRANT EXECUTE ON DW_RESULTCRITERIA_STATION TO STORETWEB;
GRANT EXECUTE ON DW_RESULT_COUNT TO STORETWEB;
GRANT EXECUTE ON DW_RESULT_DOWNLOAD_CUSTOM TO STORETWEB;
GRANT EXECUTE ON DW_RESULT_HUB_CUSTOM TO STORETWEB;
GRANT EXECUTE ON DW_STATIONCRITERIA TO STORETWEB;
GRANT EXECUTE ON DW_STATION_COUNT TO STORETWEB;
GRANT EXECUTE ON DW_STATION_DOWNLOAD_CUSTOM TO STORETWEB;
GRANT EXECUTE ON DW_STATION_HUB_CUSTOM TO STORETWEB;
GRANT EXECUTE ON DW_STATION_POPUP TO STORETWEB;
GRANT EXECUTE ON DW_STATION_SELECT TO STORETWEB;
GRANT EXECUTE ON DW_TOP_OF_PAGE TO STORETWEB;
GRANT EXECUTE ON DW_medium_select TO STORETWEB;
GRANT EXECUTE ON DW_intent_community_select TO STORETWEB;
GRANT EXECUTE ON DW_BLOB_DOWNLOAD TO STORETWEB;
GRANT EXECUTE ON DW_RESULT_DOWNLOAD_ZIP TO STORETWEB;
GRANT EXECUTE ON DW_STATION_DOWNLOAD_ZIP TO STORETWEB;
GRANT EXECUTE ON DW_STATIONCRITERIA_STN TO STORETWEB;
GRANT EXECUTE ON DW_batch_download_pickup TO STORETWEB;

SPOOL OFF
